==> voreen-src-4.4-win.zip: voreen-src-4.4-win/modules/base/processors/image/imagemasking.h <==
/***********************************************************************************
 *                                                                                 *
 * Voreen - The Volume Rendering Engine                                            *
 *                                                                                 *
 * Copyright (C) 2005-2013 University of Muenster, Germany.                        *
 * Visualization and Computer Graphics Group <http://viscg.uni-muenster.de>        *
 * For a list of authors please refer to the file "CREDITS.txt".                   *
 *                                                                                 *
 * This file is part of the Voreen software package. Voreen is free software:      *
 * you can redistribute it and/or modify it under the terms of the GNU General     *
 * Public License version 2 as published by the Free Software Foundation.          *
 *                                                                                 *
 * Voreen is distributed in the hope that it will be useful, but WITHOUT ANY       *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR   *
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.      *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License in the file   *
 * "LICENSE.txt" along with this file. If not, see <http://www.gnu.org/licenses/>. *
 *                                                                                 *
 * For non-commercial academic use see the license exception specified in the file *
 * "LICENSE-academic.txt". To get information about commercial licensing please    *
 * contact the authors.                                                            *
 *                                                                                 *
 ***********************************************************************************/

#ifndef VRN_IMAGEMASKING_H
#define VRN_IMAGEMASKING_H

#include "voreen/core/processors/imageprocessorbypassable.h"
#include "voreen/core/ports/renderport.h"
#include "voreen/core/properties/vectorproperty.h"

namespace voreen {

/**
 * Masks the input by a mask color.
 */
class VRN_CORE_API ImageMasking : public ImageProcessorBypassable {
public:
    ImageMasking();
    virtual Processor* create() const;

    virtual std::string getClassName() const  { return "ImageMasking"; }
    virtual std::string getCategory() const   { return "Image Processing"; }
    virtual CodeState getCodeState() const    { return CODE_STATE_STABLE; }

protected:
    virtual void setDescriptions() {
        setDescription("Masks the input image: All fragments matching the mask color in the mask texture are cleared.");
    }

    void process();

    RenderPort inport_;
    RenderPort inportMask_;
    RenderPort outport_;

    FloatVec4Property maskColor_;
};

} // namespace voreen

#endif //VRN_IMAGEMASKING_H

==> voreen-src-5.0.1-win.zip: voreen-src-5.0.1-win/modules/base/processors/image/imagemasking.h <==
/***********************************************************************************
 *                                                                                 *
 * Voreen - The Volume Rendering Engine                                            *
 *                                                                                 *
 * Copyright (C) 2005-2018 University of Muenster, Germany,                        *
 * Department of Computer Science.                                                 *
 * For a list of authors please refer to the file "CREDITS.txt".                   *
 *                                                                                 *
 * This file is part of the Voreen software package. Voreen is free software:      *
 * you can redistribute it and/or modify it under the terms of the GNU General     *
 * Public License version 2 as published by the Free Software Foundation.          *
 *                                                                                 *
 * Voreen is distributed in the hope that it will be useful, but WITHOUT ANY       *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR   *
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.      *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License in the file   *
 * "LICENSE.txt" along with this file. If not, see <http://www.gnu.org/licenses/>. *
 *                                                                                 *
 * For non-commercial academic use see the license exception specified in the file *
 * "LICENSE-academic.txt". To get information about commercial licensing please    *
 * contact the authors.                                                            *
 *                                                                                 *
 ***********************************************************************************/

#ifndef VRN_IMAGEMASKING_H
#define VRN_IMAGEMASKING_H

#include "voreen/core/processors/imageprocessorbypassable.h"
#include "voreen/core/ports/renderport.h"
#include "voreen/core/properties/colorproperty.h"

namespace voreen {

/**
 * Masks the input by a mask color.
 */
class VRN_CORE_API ImageMasking : public ImageProcessorBypassable {
public:
    ImageMasking();
    virtual Processor* create() const;

    virtual std::string getClassName() const  { return "ImageMasking"; }
    virtual std::string getCategory() const   { return "Image Processing"; }
    virtual CodeState getCodeState() const    { return CODE_STATE_STABLE; }

protected:
    virtual void setDescriptions() {
        setDescription("Masks the input image: All fragments matching the mask color in the mask texture are cleared.");
    }

    void process();

    RenderPort inport_;
    RenderPort inportMask_;
    RenderPort outport_;

    ColorProperty maskColor_;
};

} // namespace voreen

#endif //VRN_IMAGEMASKING_H
